@@ -4,12 +4,17 @@ Description : Omit
 LastEditors: Rustle Karl
 LastEditTime: 2021.04.25 10:21
 '''
-from . import atools, iotools, vtools, avtools
+from . import atools, avtools, etools, vtools
 
+try:
+    from .etools import view
+except ImportError as e:
+    def view():
+        raise e
 
 __all__ = [
     'atools',
     'avtools',
-    'iotools',
+    'etools',
     'vtools',
 ]
